import React from 'react';
import ReactDOM from 'react-dom';
import UpArrow from 'colby-wp-svg/jsx/up-arrow';
import _ from 'lodash';

class BackToTop extends React.Component {
  constructor(props) {
    super(props);

    this.state = {
      visible: false,
    };

    this.handleScroll = _.debounce(this.handleScroll.bind(this), 100);
  }

  componentDidMount() {
    this.handleScroll();
    window.addEventListener('scroll', this.handleScroll);
  }

  handleScroll() {
    if (window.scrollY > 600 && this.state.visible !== true) {
      this.setState({ visible: true });
    } else if (window.scrollY <= 600 && this.state.visible === true) {
      this.setState({ visible: false });
    }
  }

  render() {
    return (
      <div
        style={{
          opacity: this.state.visible ? '1' : '0',
          pointerEvents: this.state.visible ? 'all' : 'none',
          position: 'fixed',
          bottom: '1rem',
          right: '1rem',
          transition: 'opacity .2s',
          zIndex: '9999',
        }}
      >
        <button
          className="goToTopButton"
          style={{
            backgroundColor: 'rgba(0, 0, 0, .6)',
            border: '1px solid rgba(255, 255, 255, .2)',
            borderRadius: 2,
          }}
          onClick={() => {
            window.scroll({
              top: 0,
              behavior: 'smooth',
              cursor: 'pointer',
            });
          }}
        >
          <UpArrow title="Back to Top" />
        </button>
      </div>
    );
  }
}

const init = () => {
  const body = document.querySelector('body');
  if (!body || window.innerHeight < 300) {
    return;
  }

  const backToTop = document.createElement('DIV');
  body.appendChild(backToTop);

  ReactDOM.render(<BackToTop />, backToTop);
};

window.addEventListener('load', init);
